@@ -3,14 +3,10 @@ package version;
 
 use 5.006002;
 use strict;
-use warnings::register;
-if ($] >= 5.015) {
-    warnings::register_categories(qw/version/);
-}
 
 use vars qw(@ISA $VERSION $CLASS $STRICT $LAX *declare *qv);
 
-$VERSION = 0.9910;
+$VERSION = 0.9911;
 $CLASS = 'version';
 
 # !!!!Delete this next block completely when adding to Perl core!!!!
