@@ -119,18 +119,11 @@ package version::vpp;
 
 use 5.006002;
 use strict;
-use warnings::register;
 
 use Config;
-use vars qw($VERSION $CLASS @ISA $LAX $STRICT $WARN_CATEGORY);
-$VERSION = 0.9910;
+use vars qw($VERSION $CLASS @ISA $LAX $STRICT);
+$VERSION = 0.9911;
 $CLASS = 'version::vpp';
-if ($] > 5.015) {
-    warnings::register_categories(qw/version/);
-    $WARN_CATEGORY = 'version';
-} else {
-    $WARN_CATEGORY = 'numeric';
-}
 
 require version::regex;
 *version::vpp::is_strict = \&version::regex::is_strict;
@@ -155,6 +148,16 @@ use overload (
     'abs'      => \&vnoop,
 );
 
+eval "use warnings";
+if ($@) {
+    eval '
+	package
+	warnings;
+	sub enabled {return $^W;}
+	1;
+    ';
+}
+
 sub import {
     no strict 'refs';
     my ($class) = shift;
@@ -193,7 +196,7 @@ sub import {
     }
 
     if (exists($args{'UNIVERSAL::VERSION'})) {
-	no warnings qw/redefine/;
+	local $^W;
 	*UNIVERSAL::VERSION
 		= \&{$CLASS.'::_VERSION'};
     }
@@ -718,10 +721,6 @@ sub numify {
     my $digit = $self->{version}[0];
     my $string = sprintf("%d.", $digit );
 
-    if ($alpha and warnings::enabled()) {
-	warnings::warn($WARN_CATEGORY, 'alpha->numify() is lossy');
-    }
-
     for ( my $i = 1 ; $i < $len ; $i++ ) {
 	$digit = $self->{version}[$i];
 	if ( $width < 3 ) {
@@ -758,14 +757,15 @@ sub normal {
     }
     my $alpha = $self->{alpha} || "";
     my $qv = $self->{qv} || "";
+    if ($alpha and not $qv) {
+	# can't do this
+	require Carp;
+	Carp::croak("Invalid version method call");
+    }
     my $len = $#{$self->{version}};
     my $digit = $self->{version}[0];
     my $string = sprintf("v%d", $digit );
 
-    if ($alpha and warnings::enabled()) {
-	warnings::warn($WARN_CATEGORY, 'alpha->normal() is lossy');
-    }
-
     for ( my $i = 1 ; $i < $len ; $i++ ) {
 	$digit = $self->{version}[$i];
 	$string .= sprintf(".%d", $digit);
@@ -773,7 +773,12 @@ sub normal {
 
     if ( $len > 0 ) {
 	$digit = $self->{version}[$len];
-	$string .= sprintf(".%0d", $digit);
+	if ( $alpha ) {
+	    $string .= sprintf("_%0d", $digit);
+	}
+	else {
+	    $string .= sprintf(".%0d", $digit);
+	}
     }
 
     if ( $len <= 2 ) {
