@@ -833,11 +833,6 @@ Perl_vnumify(pTHX_ SV *vs)
     }
 
 
-    if (alpha) {
-	Perl_ck_warner(aTHX_ packWARN(WARN_NUMERIC),
-		       "alpha->numify() is lossy");
-    }
-
     /* attempt to retrieve the version array */
     if ( !(av = MUTABLE_AV(SvRV(*hv_fetchs(MUTABLE_HV(vs), "version", FALSE))) ) ) {
 	return newSVpvs("0");
@@ -923,11 +918,8 @@ Perl_vnormal(pTHX_ SV *vs)
 	alpha = TRUE;
     if ( hv_exists(MUTABLE_HV(vs), "qv", 2) )
 	qv = TRUE;
-
-    if (alpha) {
-	Perl_ck_warner(aTHX_ packWARN(WARN_NUMERIC),
-		       "alpha->normal() is lossy");
-    }
+    if (alpha && ! qv)
+	Perl_croak(aTHX_ "Invalid version method call");
 
     av = MUTABLE_AV(SvRV(*hv_fetchs(MUTABLE_HV(vs), "version", FALSE)));
 
@@ -952,7 +944,10 @@ Perl_vnormal(pTHX_ SV *vs)
 	/* handle last digit specially */
 	SV * tsv = *av_fetch(av, len, 0);
 	digit = SvIV(tsv);
-	Perl_sv_catpvf(aTHX_ sv, ".%"IVdf, (IV)digit);
+	if ( alpha )
+	    Perl_sv_catpvf(aTHX_ sv, "_%"IVdf, (IV)digit);
+	else
+	    Perl_sv_catpvf(aTHX_ sv, ".%"IVdf, (IV)digit);
     }
 
     if ( len <= 2 ) { /* short version, must be at least three */
